=======
Credits
=======

Development Lead
----------------

* Costas Tyfoxylos <costas.tyf@gmail.com>

Contributors
------------

* Michaël Arnauts <michael.arnauts@gmail.com>
* Amy Nagle <kabi-git@openmuffin.com>
* Jeremy Wiebe <jrwiebe@uwaterloo.ca>
* Chris Helming <cwhits@rit.edu>
